@@ -8,7 +8,7 @@ import { rollup } from 'rollup';
 
 import { nodeResolve } from '..';
 
-import { getCode, getImports, testBundle } from '../../../util/test';
+import { evaluateBundle, getCode, getImports, testBundle } from '../../../util/test';
 
 process.chdir(join(__dirname, 'fixtures'));
 
@@ -44,6 +44,21 @@ test('finds and converts a basic CommonJS module', async (t) => {
   t.is(module.exports, 'It works!');
 });
 
+test('handles cyclic CommonJS modules', async (t) => {
+  const bundle = await rollup({
+    input: 'cyclic-commonjs/main.js',
+    onwarn(warning) {
+      if (warning.code !== 'CIRCULAR_DEPENDENCY') {
+        t.fail(`Unexpected warning:\n${warning.code}\n${warning.message}`);
+      }
+    },
+    plugins: [nodeResolve(), commonjs()]
+  });
+  const { module } = await testBundle(t, bundle);
+
+  t.is(module.exports.main, 'main');
+});
+
 test('handles a trailing slash', async (t) => {
   const bundle = await rollup({
     input: 'trailing-slash.js',
@@ -258,6 +273,33 @@ test('allows custom moduleDirectories with legacy customResolveOptions.moduleDir
   t.snapshot(warnings);
 });
 
+test('moduleDirectories option rejects paths that contain a slash', async (t) => {
+  t.throws(
+    () =>
+      nodeResolve({
+        moduleDirectories: ['some/path']
+      }),
+    {
+      message: /must only contain directory names/
+    }
+  );
+});
+
+test('allows custom modulePaths', async (t) => {
+  const bundle = await rollup({
+    input: 'custom-module-path/main.js',
+    onwarn: failOnWarn(t),
+    plugins: [
+      nodeResolve({
+        modulePaths: [join(process.cwd(), 'custom-module-path/node_modules')]
+      })
+    ]
+  });
+
+  const { dependency } = await evaluateBundle(bundle);
+  t.is(dependency, 'DEPENDENCY');
+});
+
 test('ignores deep-import non-modules', async (t) => {
   const warnings = [];
   const bundle = await rollup({
